@@ -32,7 +32,7 @@ package Apache2::AMFWURFLFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "3.04";
+  $VERSION= "3.05";
   my $CommonLib = new Apache2::AMFCommonLib ();
  
   my %Capability;
@@ -47,11 +47,10 @@ package Apache2::AMFWURFLFilter;
   $MobileArray{'symbian'}='mobile';
   $MobileArray{'midp'}='mobile';
   $MobileArray{'android'}='mobile';
-  $MobileArray{'iphone'}='mobile';
+  $MobileArray{'phone'}='mobile';
   $MobileArray{'ipod'}='mobile';
   $MobileArray{'google'}='mobile';
   $MobileArray{'novarra'}='mobile';
-  $MobileArray{'smartphone'}='mobile';
   $MobileArray{'htc'}='mobile';
   my $mobileversionurl="none";
   my $fullbrowserurl="none";
@@ -155,7 +154,14 @@ sub loadConfigFile {
 			 } else {
 				$listall="true";
 				$CommonLib->printLog('CapabilityList not setted so the default value is "all"');
-			 }	
+		}	
+	      	 if ($ENV{AMFMobileKeys}) {
+				my @dummyMobileKeys = split(/,/, $ENV{AMFMobileKeys});
+				foreach $dummy (@dummyMobileKeys) {
+				      $MobileArray{$dummy}='mobile';
+				}
+				      $CommonLib->printLog("AMFMobileKeys is: $ENV{AMFMobileKeys}");
+		} 	
 	             
 	      	 if ($ENV{LoadWebPatch}) {
 				$loadwebpatch=$ENV{LoadWebPatch};
@@ -603,6 +609,7 @@ sub handler {
 						$ArrayCapFound{$string_tofound}=$dummy;
 						my $upper2=uc($string_tofound);
 						$f->subprocess_env("AMF_$upper2" => $ArrayCapFound{$string_tofound});
+						$f->pnotes("$string_tofound" => $ArrayCapFound{$string_tofound});
 					}
 					$id=$ArrayCapFound{id};								   
 				  } else {
@@ -611,18 +618,14 @@ sub handler {
 						$variabile2="$variabile2$capability2=$ArrayCapFound{$capability2}&";
 						my $upper=uc($capability2);
 						$f->subprocess_env("AMF_$upper" => $ArrayCapFound{$capability2});
+						$f->pnotes("$capability2" => $ArrayCapFound{$capability2});
 					}
 					$variabile2="id=$id&$variabile2";
 					$f->subprocess_env("AMF_ID" => $id);
+					$f->pnotes('id' => $id);
 					$cacheSystem->store( 'wurfl-id', $id, $variabile2 );
 					$cacheSystem->store( 'wurfl-ua', $user_agent, $id);
 				  }
-	              $f->pnotes('max_image_width' => $ArrayCapFound{max_image_width}); 
-				  $f->pnotes('max_image_height' => $ArrayCapFound{max_image_height});
-				  $f->pnotes('device_claims_web_support' => $ArrayCapFound{device_claims_web_support});	
-				  $f->pnotes('is_wireless_device' => $ArrayCapFound{is_wireless_device});	
-				  $f->pnotes('is_transcoder' => $ArrayCapFound{is_transcoder});
-				  $f->pnotes('id' => $id);
 					if ($cookiecachesystem eq "true") {
 						$f->err_headers_out->set('Set-Cookie' => "amf=$id; path=/;");	
 					}		  			  
